@@ -15,26 +15,32 @@ from arango.wal import WriteAheadLog
 class ArangoClient(object):
     """ArangoDB client.
 
-    :param protocol: the internet transfer protocol (default: ``"http"``)
+    :param protocol: The internet transfer protocol (default: ``"http"``).
     :type protocol: str | unicode
-    :param host: ArangoDB host (default: ``"localhost"``)
+    :param host: ArangoDB server host (default: ``"localhost"``).
     :type host: str | unicode
-    :param port: ArangoDB port (default: ``8529``)
+    :param port: ArangoDB server port (default: ``8529``).
     :type port: int or str
-    :param username: ArangoDB username (default: ``"root"``)
+    :param username: ArangoDB default username (default: ``"root"``).
     :type username: str | unicode
-    :param password: ArangoDB password (default: ``""``)
-    :param verify: check the connection during initialization. Root privileges
-        are required to use this check.
+    :param password: ArangoDB default password (default: ``""``).
+    :param verify: Check the connection during initialization. Root privileges
+        are required to use this flag.
     :type verify: bool
-    :param http_client: the HTTP client object
+    :param http_client: Custom HTTP client to override the default one with.
+        Please refer to the API documentation for more details.
     :type http_client: arango.http_clients.base.BaseHTTPClient
-    :param enable_logging: log all API requests
+    :param enable_logging: Log all API requests as debug messages.
     :type enable_logging: bool
-    :param check_cert: verify SSL certificate when making HTTP requests
+    :param check_cert: Verify SSL certificate when making HTTP requests. This
+        flag is ignored if a custom **http_client** is specified.
     :type check_cert: bool
-    :param use_session: use session when making HTTP requests
+    :param use_session: Use session when making HTTP requests. This flag is
+        ignored if a custom **http_client** is specified.
     :type use_session: bool
+    :param logger: Custom logger to record the API requests with. The logger's
+        ``debug`` method is called.
+    :type logger: logging.Logger
     """
 
     def __init__(self,
@@ -47,7 +53,8 @@ class ArangoClient(object):
                  http_client=None,
                  enable_logging=True,
                  check_cert=True,
-                 use_session=True):
+                 use_session=True,
+                 logger=None):
 
         self._protocol = protocol
         self._host = host
@@ -58,7 +65,7 @@ class ArangoClient(object):
             use_session=use_session,
             check_cert=check_cert
         ) if http_client is None else http_client
-        self._logging = enable_logging
+        self._logging_enabled = enable_logging
         self._conn = Connection(
             protocol=self._protocol,
             host=self._host,
@@ -67,7 +74,8 @@ class ArangoClient(object):
             username=self._username,
             password=self._password,
             http_client=self._http_client,
-            enable_logging=self._logging
+            enable_logging=self._logging_enabled,
+            logger=logger
         )
         self._wal = WriteAheadLog(self._conn)
 
@@ -156,7 +164,7 @@ class ArangoClient(object):
         :returns: whether logging is enabled
         :rtype: bool
         """
-        return self._logging
+        return self._logging_enabled
 
     @property
     def wal(self):
@@ -612,7 +620,7 @@ class ArangoClient(object):
             username=username or self._username,
             password=password or self._password,
             http_client=self._http_client,
-            enable_logging=self._logging
+            enable_logging=self._logging_enabled
         ))
 
     def create_database(self, name, users=None, username=None, password=None):
