@@ -102,11 +102,13 @@ class BaseCollection(APIWrapper):
 
         :param code: the collection status code
         :type code: int
-        :returns: the collection status text
-        :rtype: str  | unicode
+        :returns: the collection status text or ``None``
+        :rtype: str  | unicode | None
         :raises arango.exceptions.CollectionBadStatusError: if the collection
             status code is unknown
         """
+        if code is None:  # pragma: no cover
+            return None
         try:
             return self.STATUSES[code]
         except KeyError:
@@ -123,6 +125,15 @@ class BaseCollection(APIWrapper):
         """
         return self._name
 
+    @property
+    def database(self):
+        """Return the name of the database the collection belongs to.
+
+        :returns: The name of the database.
+        :rtype: str | unicode
+        """
+        return self._conn.database
+
     @api_method
     def rename(self, new_name):
         """Rename the collection.
@@ -208,10 +219,10 @@ class BaseCollection(APIWrapper):
     def properties(self):
         """Return the collection properties.
 
-        :returns: the collection properties
+        :returns: The collection properties.
         :rtype: dict
-        :raises arango.exceptions.CollectionPropertiesError: if the
-            collection properties cannot be retrieved
+        :raises arango.exceptions.CollectionPropertiesError: If the
+            collection properties cannot be retrieved.
         """
         request = Request(
             method='get',
@@ -221,24 +232,24 @@ class BaseCollection(APIWrapper):
         def handler(res):
             if res.status_code not in HTTP_OK:
                 raise CollectionPropertiesError(res)
-            result = {
-                'id': res.body['id'],
-                'name': res.body['name'],
-                'edge': res.body['type'] == 3,
-                'sync': res.body['waitForSync'],
-                'status': self._status(res.body['status']),
-                'compact': res.body['doCompact'],
-                'system': res.body['isSystem'],
-                'volatile': res.body['isVolatile'],
-                'journal_size': res.body['journalSize'],
-                'keygen': res.body['keyOptions']['type'],
-                'user_keys': res.body['keyOptions']['allowUserKeys'],
+
+            key_options = res.body.get('keyOptions', {})
+
+            return {
+                'id': res.body.get('id'),
+                'name': res.body.get('name'),
+                'edge': res.body.get('type') == 3,
+                'sync': res.body.get('waitForSync'),
+                'status': self._status(res.body.get('status')),
+                'compact': res.body.get('doCompact'),
+                'system': res.body.get('isSystem'),
+                'volatile': res.body.get('isVolatile'),
+                'journal_size': res.body.get('journalSize'),
+                'keygen': key_options.get('type'),
+                'user_keys': key_options.get('allowUserKeys'),
+                'key_increment': key_options.get('increment'),
+                'key_offset': key_options.get('offset')
             }
-            if 'increment' in res.body['keyOptions']:
-                result['key_increment'] = res.body['keyOptions']['increment']
-            if 'offset' in res.body['keyOptions']:
-                result['key_offset'] = res.body['keyOptions']['offset']
-            return result
 
         return request, handler
 
@@ -248,9 +259,9 @@ class BaseCollection(APIWrapper):
 
         Only *sync* and *journal_size* properties are configurable.
 
-        :param sync: wait for the operation to sync to disk
+        :param sync: Wait for the operation to sync to disk.
         :type sync: bool
-        :param journal_size: the journal size
+        :param journal_size: The journal size.
         :type journal_size: int
         :returns: the new collection properties
         :rtype: dict
@@ -272,22 +283,24 @@ class BaseCollection(APIWrapper):
         def handler(res):
             if res.status_code not in HTTP_OK:
                 raise CollectionConfigureError(res)
-            result = {
-                'id': res.body['id'],
-                'name': res.body['name'],
-                'edge': res.body['type'] == 3,
-                'sync': res.body['waitForSync'],
-                'status': self._status(res.body['status']),
-                'compact': res.body['doCompact'],
-                'system': res.body['isSystem'],
-                'volatile': res.body['isVolatile'],
-                'journal_size': res.body['journalSize'],
-                'keygen': res.body['keyOptions']['type'],
-                'user_keys': res.body['keyOptions']['allowUserKeys'],
-                'key_increment': res.body['keyOptions'].get('increment'),
-                'key_offset': res.body['keyOptions'].get('offset')
+
+            key_options = res.body.get('keyOptions', {})
+
+            return {
+                'id': res.body.get('id'),
+                'name': res.body.get('name'),
+                'edge': res.body.get('type') == 3,
+                'sync': res.body.get('waitForSync'),
+                'status': self._status(res.body.get('status')),
+                'compact': res.body.get('doCompact'),
+                'system': res.body.get('isSystem'),
+                'volatile': res.body.get('isVolatile'),
+                'journal_size': res.body.get('journalSize'),
+                'keygen': key_options.get('type'),
+                'user_keys': key_options.get('allowUserKeys'),
+                'key_increment': key_options.get('increment'),
+                'key_offset': key_options.get('offset')
             }
-            return result
 
         return request, handler
 
@@ -930,6 +943,7 @@ class BaseCollection(APIWrapper):
         :rtype: [dict]
         :raises arango.exceptions.IndexListError: if the list of indexes
             cannot be retrieved
+
         """
         request = Request(
             method='get',
@@ -988,7 +1002,11 @@ class BaseCollection(APIWrapper):
         return request, handler
 
     @api_method
-    def add_hash_index(self, fields, unique=None, sparse=None):
+    def add_hash_index(self,
+                       fields,
+                       unique=None,
+                       sparse=None,
+                       deduplicate=None):
         """Create a new hash index in the collection.
 
         :param fields: the document fields to index
@@ -997,6 +1015,14 @@ class BaseCollection(APIWrapper):
         :type unique: bool
         :param sparse: index ``None``'s
         :type sparse: bool
+        :param deduplicate: Controls whether inserting duplicate index values
+            from the same document into a unique array index leads to a unique
+            constraint error or not. If set to ``True`` (default), only a
+            single instance of each non-unique index values is inserted into
+            the index per document. Trying to insert a value into the index
+            that already exists will always fail, regardless of the value of
+            this field.
+        :type deduplicate: bool
         :returns: the details on the new index
         :rtype: dict
         :raises arango.exceptions.IndexCreateError: if the hash index cannot
@@ -1007,10 +1033,16 @@ class BaseCollection(APIWrapper):
             data['unique'] = unique
         if sparse is not None:
             data['sparse'] = sparse
+        if deduplicate is not None:
+            data['deduplicate'] = deduplicate
         return self._add_index(data)
 
     @api_method
-    def add_skiplist_index(self, fields, unique=None, sparse=None):
+    def add_skiplist_index(self,
+                           fields,
+                           unique=None,
+                           sparse=None,
+                           deduplicate=None):
         """Create a new skiplist index in the collection.
 
         A skiplist index is used to find the ranges of documents (e.g. time).
@@ -1021,6 +1053,14 @@ class BaseCollection(APIWrapper):
         :type unique: bool
         :param sparse: index ``None``'s
         :type sparse: bool
+        :param deduplicate: Controls whether inserting duplicate index values
+            from the same document into a unique array index leads to a unique
+            constraint error or not. If set to ``True`` (default), only a
+            single instance of each non-unique index values is inserted into
+            the index per document. Trying to insert a value into the index
+            that already exists will always fail, regardless of the value of
+            this field.
+        :type deduplicate: bool
         :returns: the details on the new index
         :rtype: dict
         :raises arango.exceptions.IndexCreateError: if the skiplist index
@@ -1031,6 +1071,8 @@ class BaseCollection(APIWrapper):
             data['unique'] = unique
         if sparse is not None:
             data['sparse'] = sparse
+        if deduplicate is not None:
+            data['deduplicate'] = deduplicate
         return self._add_index(data)
 
     @api_method
@@ -1138,3 +1180,83 @@ class BaseCollection(APIWrapper):
             return not res.body['error']
 
         return request, handler
+
+    @api_method
+    def user_access(self, username):
+        """Return a user's access details for the collection.
+
+        Appropriate permissions are required in order to execute this method.
+
+        :param username: The name of the user.
+        :type username: str | unicode
+        :returns: The access details (e.g. ``"rw"``, ``None``)
+        :rtype: str | unicode | None
+        :raises: arango.exceptions.UserAccessError: If the retrieval fails.
+        """
+        request = Request(
+            method='get',
+            endpoint='/_api/user/{}/database/{}/{}'.format(
+                username, self.database, self.name
+            )
+        )
+
+        def handler(res):
+            if res.status_code in HTTP_OK:
+                result = res.body['result'].lower()
+                return None if result == 'none' else result
+            raise UserAccessError(res)
+
+        return request, handler
+
+    @api_method
+    def grant_user_access(self, username):
+        """Grant user access to the collection.
+
+        Appropriate permissions are required in order to execute this method.
+
+        :param username: The name of the user.
+        :type username: str | unicode
+        :returns: Whether the operation was successful or not.
+        :rtype: bool
+        :raises arango.exceptions.UserGrantAccessError: If the operation fails.
+        """
+        request = Request(
+            method='put',
+            endpoint='/_api/user/{}/database/{}/{}'.format(
+                username, self.database, self.name
+            ),
+            data={'grant': 'rw'}
+        )
+
+        def handler(res):
+            if res.status_code in HTTP_OK:
+                return True
+            raise UserGrantAccessError(res)
+
+        return request, handler
+
+    @api_method
+    def revoke_user_access(self, username):
+        """Revoke user access to the collection.
+
+        Appropriate permissions are required in order to execute this method.
+
+        :param username: The name of the user.
+        :type username: str | unicode
+        :returns: Whether the operation was successful or not.
+        :rtype: bool
+        :raises arango.exceptions.UserRevokeAccessError: If the operation fails.
+        """
+        request = Request(
+            method='delete',
+            endpoint='/_api/user/{}/database/{}/{}'.format(
+                username, self.database, self.name
+            )
+        )
+
+        def handler(res):
+            if res.status_code in HTTP_OK:
+                return True
+            raise UserRevokeAccessError(res)
+
+        return request, handler
