@@ -13,11 +13,11 @@ from .utils import (
 )
 
 arango_client = ArangoClient()
-db_name = generate_db_name(arango_client)
+db_name = generate_db_name()
 db = arango_client.create_database(db_name)
-col_name = generate_col_name(db)
+col_name = generate_col_name()
 col = db.create_collection(col_name)
-bad_col_name = generate_col_name(db)
+bad_col_name = generate_col_name()
 bad_col = db.collection(bad_col_name)
 
 
@@ -44,9 +44,9 @@ def test_properties():
     assert isinstance(properties['journal_size'], int)
     assert properties['keygen'] in ('autoincrement', 'traditional')
     assert isinstance(properties['user_keys'], bool)
-    if 'key_increment' in properties:
+    if properties['key_increment'] is not None:
         assert isinstance(properties['key_increment'], int)
-    if 'key_offset' in properties:
+    if properties['key_offset'] is not None :
         assert isinstance(properties['key_offset'], int)
     with pytest.raises(CollectionBadStatusError):
         assert getattr(col, '_status')(10)
@@ -80,9 +80,9 @@ def test_configure():
 
 def test_rename():
     assert col.name == col_name
-    new_name = generate_col_name(db)
+    new_name = generate_col_name()
     while new_name == bad_col_name:
-        new_name = generate_col_name(db)
+        new_name = generate_col_name()
 
     # Test rename collection
     result = col.rename(new_name)
